import React from 'react';
import axios from 'axios';
import { properties } from '../../../properties.js';
import AppStore from "./../../../stores/AppStore";
import Greeting from "./../QRScan/Greeting";
import AppointmentList from "./AppointmentList"
import DesignStore from "./../../../stores/DesignStore";
import LanguageStore from "./../../../stores/LanguageStore";

class CheckinDocument extends React.Component {

  constructor(props) {
    super(props);

    this.state = {
      display: AppStore.getDisplay(),
      error: 0,
      ap:null,
      au:null,
      list:null,
      designs : DesignStore.getDesign()
    };

    this.update = this.update.bind(this);
    this.scanDocument = this.scanDocument.bind(this);
    this.findVisitor = this.findVisitor.bind(this);
    this.setAppointment = this.setAppointment.bind(this);
   }

  componentDidMount (){
    AppStore.load();
    AppStore.on("loaded", this.update);
    DesignStore.on("design_loaded", this.update);
    LanguageStore.on("language_loaded", this.update);
  }

  findVisitor(data){
    if(data.au_name && data.au_surname){
      axios.get(properties.api_url + "/visitors/document?SID=" +
        properties.key + "&au_name=" + encodeURI(data.au_surname) + "&au_surname=" + encodeURI(data.au_name))
        .then(res => {

          if(res.data.length === 1){
            this.setState({
              ap : res.data[0].ap,
              au : res.data[0].au,
              error:0
            })
          }else if(res.data.length > 1){
            this.setState({
              list : res.data,
              error:0
            })
          }else{
            this.setState({
              error : "1"
            })
          }

        }).catch(function (error) {
          console.log(error);
        })

    }else{

      this.setState({
        error : "1"
      })

    }
  }

  setAppointment(AP, AU){
    this.setState({
      ap : AP,
      au : AU,
      error:0
    })
  }

  update(){
    this.setState({
      display : AppStore.getDisplay(),
      error:0,
      designs : DesignStore.getDesign()
    })
  }

  scanDocument(e){
    e.preventDefault();
    axios.get(properties.api_url + "/hardware/idscanner/" + this.state.display.di_scan + "?SID=" + properties.key)
      .then(res => {
        this.findVisitor(res.data);

      }).catch(function (error) {
        console.log(error);
      })
  }

  render() {
    var buttonStyles;
    if(this.state.designs){
      buttonStyles = {
        backgroundColor:this.state.designs["main_color"]
      };
    }

    if(!this.state.display){

      return ( <div id="CheckinDocument">loading ...</div> );

    }else if(this.state.error !== 0){

      return ( <div id="CheckinDocument"><h2>{LanguageStore.translate("document_scan_error")}</h2></div> )

    }else if(this.state.ap !== null){

      window.globals.jump_list = function(){
        this.setAppointment(null,null);
      }.bind(this)
      
      return ( <div id="CheckinDocument"><Greeting ap={this.state.ap} au={this.state.au} /></div> )

    }else if(this.state.list !== null){
      return ( <div id="CheckinDocument"><AppointmentList list={this.state.list} callback={this.setAppointment} /></div> )
    }

    return (
      <div className="page" id="CheckinDocument">
        <h1>{LanguageStore.translate("document_scan_title")}</h1>
        <div className="img_wrapper"><img src="/img/animation_doc.gif" alt="animation" /></div>
        <button type="button" style={buttonStyles} className="button" onClick={this.scanDocument} >{LanguageStore.translate("document_scan_btn")}</button>
      </div>
    );
  }
}

export default CheckinDocument;
