import React from 'react';
import DesignStore from "./../../../stores/DesignStore";
import CheckinSelfStore from "../../../stores/CheckinSelfStore";
import HostStore from "../../../stores/HostStore";
import axios from 'axios';
import { properties } from '../../../properties.js';
import AppStore from "./../../../stores/AppStore";
import Keyboard from 'react-simple-keyboard';
import 'react-simple-keyboard/build/css/index.css';
import LanguageStore from "./../../../stores/LanguageStore";
//import layout from "simple-keyboard-layouts/build/layouts/german";

class Register extends React.Component {

  constructor(props){
    super(props)
    this.state ={
      display: CheckinSelfStore.getCheckinSelf(),
      hosts: HostStore.loadHosts(),
      d: AppStore.getDisplay(),
      layoutName: "default",
      inputName:"",
      input: {},
      designs : DesignStore.getDesign()
    }

    this.layout = {
        default: [
          "1 2 3 4 5 6 7 8 9 0 \u00DF \u00B4 {bksp}",
          "q w e r t z u i o p \u00FC ",
          "a s d f g h j k l \u00F6 \u00E4 ",
          "{shift} < y x c v b n m , . - ",
          "{space} @"
        ],
        shift: [
          '\u00B0 ! " \u00A7 $ % & / ( ) = ? ` {bksp}',
          "Q W E R T Z U I O P \u00DC *",
          "A S D F G H J K L \u00D6 \u00C4",
          "{shift} > Y X C V B N M ; : _ }",
          "{space} @"
        ]
      };

    this.update = this.update.bind(this);
    this.checkResults = this.checkResults.bind(this);
    this.handleChange = this.handleChange.bind(this);
    this.submit = this.submit.bind(this);
    this.updateHosts = this.updateHosts.bind(this);
    this.listHosts = this.listHosts.bind(this);
    this.toggleHostList = this.toggleHostList.bind(this);
    this.scanID = this.scanID.bind(this);
    this.saveInputValues = this.saveInputValues.bind(this);
  }

  handleChange(event) {}

  submit(event) {
    event.preventDefault();
    const data = new FormData(event.target);
    var object = {};
    data.forEach((value, key) => {object[key] = value});
    CheckinSelfStore.checkIn(object);
  }

  componentDidMount (){
    DesignStore.on("design_loaded", this.update);
    CheckinSelfStore.on("checkinSelfStore_loaded", this.update);
    HostStore.on("hosts_loaded", this.updateHosts);
    CheckinSelfStore.on("QRCoded_scanned", this.checkResults);
    AppStore.on("loaded", this.update);
  }

  checkResults(){
    console.log("update");
    this.setState({
      display : CheckinSelfStore.getCheckinSelf()
    })
  }

  scanID(e){
    e.preventDefault();
    axios.get(properties.api_url + "/hardware/idscanner/" + this.state.d.di_scan + "?SID=" + properties.key)
      .then(res => {
        if(res.data.au_name){
          window.$("#aps_name").val(res.data.au_name);
          this.saveInputValues(window.$("#aps_name").attr("name"), res.data.au_name);
        }
        if(res.data.au_surname){
          window.$("#aps_surname").val(res.data.au_surname);
          this.saveInputValues(window.$("#aps_surname").attr("name"), res.data.au_surname);
        }
      }).catch(function (error) {
        console.log(error);
      })
  }

  saveInputValues(inputName, val){
    let updatedInputObj = {
      ...this.state.input,
      [inputName]: val
    }

    this.setState(
      {
        input: updatedInputObj
      },
      () => {
        this.keyboardRef.keyboard.setInput(val);
      }
    );
  }

  updateHosts(){
    this.setState({
      hosts : HostStore.getHosts()
    })
  }

  update(){
    this.setState({
      designs : DesignStore.getDesign(),
      d:AppStore.getDisplay(),
      display : CheckinSelfStore.getCheckinSelf(),
    })
  }

  hostSelected(e, host){
    window.$("#aps_host_name").val(host.pe_name + ", " + host.pe_vorname);
    window.$("#aps_host").val(host.pe_id);
    this.toggleHostList();
  }

  listHosts(){
    let styles = null
    if(this.state.designs){
      styles = {
        color: this.state.designs["main_font_color"],
        backgroundColor:this.state.designs["main_color"]
      };
    }
    return(
      <div id="host_list" style={styles}>
        <h2>{LanguageStore.translate("self_register_contact")}</h2>
        <ul>
          { this.state.hosts.map(function(host, index){
            return <li onClick={(e) => this.hostSelected(e, host)} key={ index }>{host.pe_name}, {host.pe_vorname}</li>;
          }.bind(this)) }
        </ul>
      </div>
    )
  }

  toggleHostList(){
    window.$("#host_list").toggle();
  }

  onChangeAll = inputObj => {
    this.setState({
      input: inputObj
    });
  };

  onKeyPress = button => {
    if (button === "{shift}" || button === "{lock}") this.handleShift();
  };

  handleShift = () => {
    let layoutName = this.state.layoutName;

    this.setState({
      layoutName: layoutName === "default" ? "shift" : "default"
    });
  };

  onChangeInput = event => {
    this.saveInputValues(this.state.inputName, event.target.value);
  };

  setActiveInput = (e) => {
    let inputName = e.target.name;
      this.setState({
        inputName: inputName
      }, () => {
        console.log("Active input", inputName);
      });
    }


  render() {
    let now =new Date().toISOString().split('T')[0];
    let hosts ="";

    let buttonStyles = null
    if(this.state.designs){
      buttonStyles = {
        backgroundColor:this.state.designs["main_color"]
      };
    }

    if(this.state.hosts !== undefined){
      hosts = this.listHosts();
    }

    let showScanner = this.state.d.di_scan !== "-1";

    return (

      <div id="self_checkin">
          <h1>{LanguageStore.translate("self_register_title")}</h1>
          {hosts}
          <div className="reg_wrapper">
            <div className="form_wrapper">
              <form onSubmit={this.submit}>

                <div className="form-group">
                  <label>{LanguageStore.translate("self_register_subject")}</label>
                  <input
                    type="text"
                    name="aps_subject"
                    className="form-control"
                    onChange={e => this.onChangeInput(e)}
                    onFocus={ e => this.setActiveInput(e)}
                    value={this.state.input['aps_subject'] || ""}
                    required   />
                </div>

                <div className="form-group">
                  <label>{LanguageStore.translate("self_register_date")}</label>
                  <input type="date" name="aps_date" className="form-control" value={now} readOnly />
                </div>

                <div className="form-group">
                  <label>{LanguageStore.translate("self_register_name")}</label>
                  <input
                    id ="aps_name"
                    type="text"
                    name="aps_name"
                    className="form-control"
                    value={this.state.input['aps_name'] || ""}
                    onFocus={this.setActiveInput}
                    onChange={e => this.onChangeInput(e)}
                    required />
                    {showScanner === true &&
                      <button
                        style={buttonStyles}
                        type="button"
                        className="button"
                        onClick={this.scanID} >{LanguageStore.translate("self_register_scan")}</button>
                    }
                </div>
                <div className="form-group">
                  <label>{LanguageStore.translate("self_register_surname")}</label>
                  <input
                    id="aps_surname"
                    type="text"
                    name="aps_surname"
                    className="form-control"
                    onFocus={this.setActiveInput}
                    value={this.state.input['aps_surname'] || ""}
                    onChange={e => this.onChangeInput(e)}
                    required />
                </div>
                <div className="form-group">
                  <label>{LanguageStore.translate("self_register_company")}</label>
                  <input
                    type="text"
                    name="aps_company"
                    className="form-control"
                    value={this.state.input['aps_company'] || ""}
                    onFocus={this.setActiveInput}  />
                </div>
                <div className="form-group">
                  <label>{LanguageStore.translate("self_register_mail")}</label>
                  <input
                    type="email"
                    name="aps_email"
                    className="form-control"
                    value={this.state.input['aps_email'] || ""}
                    onFocus={this.setActiveInput}  />
                </div>
                <div className="form-group">
                  <label>{LanguageStore.translate("self_register_mobile")}</label>
                  <input
                    type="text"
                    name="aps_mobile"
                    className="form-control"
                    onFocus={this.setActiveInput}
                    value={this.state.input['aps_mobile'] || ""} />
                </div>
                <div className="form-group">
                  <label>{LanguageStore.translate("self_register_categorie")}</label>
                  <select type="text" name="aps_type"
                  className="form-control"  required onChange={e => this.onChangeInput(e)} >
                    {this.state.display.categories.map((cat, i) => {
                      return (<option key={i} value={cat.vt_id} >{cat.vt_name}</option>)
                    })}
                  </select>
                </div>
                <div className="form-group">
                  <label>{LanguageStore.translate("self_register_desc")}</label>
                  <textarea
                    name="aps_descr"
                    type="text"
                    className="form-control"
                    onFocus={this.setActiveInput}
                    value={this.state.input['aps_descr'] || ""} />
                </div>
                <div className="form-group">
                  <label>{LanguageStore.translate("self_register_contact")}</label>
                  <div>
                    <input
                      id="aps_host_name"
                      name="aps_host_name"
                      type="text"
                      onFocus={this.setActiveInput}
                      className="form-control"
                      value={this.state.input['aps_host_name'] || ""}
                      onChange={e => this.onChangeInput(e)}
                      required />
                    <input id="aps_host" name="aps_pe_id" type="hidden"
                     className="form-control" />
                    <input id="aps_status" name="aps_status" value="pending"
                    type="hidden" className="form-control" />

                    <button
                      style={buttonStyles}
                      type="button"
                      className="button"
                      onClick={this.toggleHostList}>
                        {LanguageStore.translate("self_register_search")}
                      </button>
                  </div>
                </div>

                <input type="hidden" name="aps_site_id" value={window.globals["site_id"]} />

                <input
                  type="submit"
                  style={buttonStyles}
                  className="button button-small"
                  value={LanguageStore.translate("self_register_subscribe")} />
              </form>
            </div>
            <div className="vkeyboard">
              <Keyboard
                layout={this.layout}
                ref={r => (this.keyboardRef = r)}
                layoutName={this.state.layoutName}
                inputName={this.state.inputName}
                onChangeAll={inputObj => this.onChangeAll(inputObj)}
                onKeyPress={button => this.onKeyPress(button)}
              />
            </div>
          </div>
      </div>
    );
  }
}

export default Register;
