import React from 'react';
import Greeting from "./Greeting";
import Bye from "./Bye";
import Early from "./Early";
import Late from "./Late";
import Guidance from "./Guidance";
import WelcomeMessage from "./WelcomeMessage";
import Checklist from "./Checklist";
import CheckinStore from "./../../../stores/CheckinStore";
import MSButton from "./../../UI/MSButton";
import BackButton from "./../../UI/BackButton";

class CheckinProzess extends React.Component {

  constructor(props){
    super(props)

    CheckinStore.init(props.au.au_id);

    this.state = {
      ap : props.ap,
      au : props.au,
      checkin: CheckinStore.getCheckin(),
      status: CheckinStore.getStatus()
    }
    this.update =  this.update.bind(this)
    this.back =  this.back.bind(this)
  }

  componentDidMount (){
    CheckinStore.on("status_changed", this.update);
    CheckinStore.on("checkin_loaded", this.update);
  }

  update(){
    this.setState({
      checkin : CheckinStore.getCheckin(),
      status : CheckinStore.getStatus()
    })
  }

  back(){
    let action = window.globals.jump_greeting;
    window.globals.jump_greeting = undefined;
    action();
  }

  render() {

    let step = null;

    if(this.state.checkin === null){
      step =  (<div>loading ...</div>)
    }else if(this.state.status === "bye" || this.state.status === "gone"){
      step =  (<Bye au={this.state.au} ap={this.state.ap} />)
      window.globals.jump_greeting = undefined;
    }else if(this.state.status === "greeting"){
      step =  (<Greeting au={this.state.au} ap={this.state.ap} />)
      window.globals.jump_greeting = undefined;
    }else if(this.state.status === "checklist" ){
      step =  (<Checklist checkin={this.state.checkin} type="out" />)
    }else if(this.state.status === "guidance" ){
      step =  (<Guidance checkin={this.state.checkin} />)
    }else if(this.state.status === "done" ){
      step =  (<WelcomeMessage au={this.state.checkin.au} ap={this.state.checkin.ap} />)
      window.globals.jump_greeting = undefined;
    }else if(this.state.status === "checkedIn" ){
      step =  (<WelcomeMessage au={this.state.checkin.au} ap={this.state.checkin.ap} />)
    }else if(this.state.status === "early" ){
        step =  (<Early au={this.state.checkin.au} ap={this.state.checkin.ap} />)
    }else if(this.state.status === "late" ){
        step =  (<Late au={this.state.checkin.au} ap={this.state.checkin.ap} />)
    }else {
      step =(<div>{this.state.status}</div>)
    }
    console.log(this.state.checkin);
    return (
      <div>

        {this.state.checkin !== null && this.state.checkin.ap !== null && this.state.checkin.ap.ap_title !== undefined &&
          <h1>Termin: {this.state.checkin.ap.ap_title}</h1>
        }

        {step}

        {window.globals.jump_greeting !== undefined &&
          <BackButton  id="msback" action={this.back} />
        }

      </div>
    );
  }
}

export default CheckinProzess;
