import dispatcher from "../Dispatcher";
import {EventEmitter} from "events";
import axios from 'axios';
import { properties } from '../properties.js';
import rest from './../restclient.js';

class CheckinStore extends EventEmitter {

    constructor() {
        super();
        const queryString = require('query-string');
        const parsed = queryString.parse(window.location.search);

        this.status = "";
        this.checkinStarted = false;
        this.display = { di_id:parsed.di_id, };
        this.load = this.load.bind(this);
        this.checklist = [];
        this.guidanceDone = this.guidanceDone.bind(this);
        this.init = this.init.bind(this);
        this.checkIn = this.checkIn.bind(this);
        this.handleCheckInFail = this.handleCheckInFail.bind(this);
        this.calcStatus = this.calcStatus.bind(this);
        this.checkinResult = null;

        this.au_id = null;

        this.load();
    }

    sendCheckList(data){
      axios.post(properties.api_url + "/checklist/?SID=" + properties.key, data)
        .then(res => {
          this.checkIn();
        }).catch(function (error) {
          console.log(error);
        })
    }

    guidanceDone(){
      this.checkIn();
    }

    init(au_id){
      this.au_id = au_id;
      this.checkinStarted = false;
      this.checkinResult = null;
      this.checkIn();
    }

    load(){
      axios.get(properties.api_url + "/display/" + this.di_id + "?SID=" + properties.key)
        .then(res => {
          this.display = res.data.designs;
          this.emit("loaded");
        }).catch(function (error) {
          console.log(error);
        })
    }

    getCheckInlist(){
      return this.checklist;
    }

    loadCheckInlist(id){
      axios.get(properties.api_url + "/checklist/" + this.checkinResult.ap.ap_checklist + "?SID=" + properties.key)
        .then(res => {
          this.checklist  = res.data;
          this.emit("checkInList_loaded");
        }).catch(function (error) {
          console.log(error);
        })
    }

    handleCheckInFail(error){
      this.checkinResult =  error.response.data
      this.emit("checkin_loaded");
      this.calcStatus();
    }

    calcStatus(){
      if(this.checkinResult === null ||
        this.checkinResult === undefined ||
        this.checkinResult.au === null ||
         this.checkinResult.au === undefined){
        return;
      }

      if( (this.checkinResult.ap.ap_checklist !== "" && this.checkinResult.ap.ap_checklist !== "-1" )
       && (this.checkinResult.au.au_checklist_done === null || this.checkinResult.au.au_checklist_done !== "1" ) ){
        this.status = "checklist"
      }else if( this.checkinResult.guidance !== null && this.checkinResult.guidance.length > 0){
        this.status = "guidance"
      }else if( this.checkinResult && this.checkinResult.success === true ){
        this.status = "done"
      }else if( this.checkinResult && this.checkinResult.time === "late"){
        this.status = "late"
      }else if( this.checkinResult && this.checkinResult.time === "early"){
        this.status = "early"
      }else{
          console.log("???");
      }
      console.log("status :" + this.status);
      this.emit("status_changed");
    }

    checkIn(){
      this.checkinResult = null;
      axios.get(properties.api_url + "/visitor/" + this.au_id + "/checkin/?SID=" + properties.key).then(res => {
          this.checkinResult = res.data;
          this.emit("checkin_loaded");
          this.calcStatus();
        }).catch(this.handleCheckInFail)
    }



    getCheckin(){
      return this.checkinResult;
    }

    getStatus() {
      return this.status;
    }

    handleActions(){}
}

const checkinStore = new CheckinStore();
dispatcher.register(checkinStore.handleActions.bind(checkinStore));
export default checkinStore;
